pub struct SequenceMetadata {
pub name: String,
pub description: Option<String>,
pub length: usize,
pub sha512t24u: String,
pub md5: String,
pub alphabet: AlphabetType,
pub fai: Option<FaiMetadata>,
}Expand description
Metadata for a single sequence, including its name, length, digests, and alphabet type.
Fields
name: Stringdescription: Option<String>Description from FASTA header (text after first whitespace).
length: usizesha512t24u: Stringmd5: Stringalphabet: AlphabetTypefai: Option<FaiMetadata>Trait Implementations
Sourceimpl Clone for SequenceMetadata
impl Clone for SequenceMetadata
Sourcefn clone(&self) -> SequenceMetadata
fn clone(&self) -> SequenceMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SequenceMetadata
impl Debug for SequenceMetadata
Sourceimpl Default for SequenceMetadata
impl Default for SequenceMetadata
Sourcefn default() -> SequenceMetadata
fn default() -> SequenceMetadata
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SequenceMetadata
impl<'de> Deserialize<'de> for SequenceMetadata
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SequenceMetadata, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SequenceMetadata, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl SequenceMetadataExt for SequenceMetadata
impl SequenceMetadataExt for SequenceMetadata
Sourcefn disk_size(&self, mode: &StorageMode) -> usize
fn disk_size(&self, mode: &StorageMode) -> usize
Calculate the disk size in bytes for this sequence.
Sourceimpl Serialize for SequenceMetadata
impl Serialize for SequenceMetadata
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more